@@ -1,5 +1,5 @@
 
-/* $Id: ec_threads.h,v 1.8 2004/07/24 10:43:21 alor Exp $ */
+/* $Id: ec_threads.h,v 1.11 2004/11/05 14:11:52 alor Exp $ */
 
 #ifndef EC_THREADS_H
 #define EC_THREADS_H
@@ -13,9 +13,10 @@ struct ec_thread {
    pthread_t id;
 };
 
-enum {
-   EC_SELF = 0,
-};
+/* a value to be used to return errors in fuctcions using pthread_t values */
+pthread_t EC_PTHREAD_NULL;
+#define EC_PTHREAD_SELF EC_PTHREAD_NULL
+#define PTHREAD_ID(id)  (*(unsigned long*)&(id)) 
 
 #define EC_THREAD_FUNC(x) void * x(void *args)
 #define EC_THREAD_PARAM  args
@@ -30,7 +31,7 @@ EC_API_EXTERN void ec_thread_init(void);
 EC_API_EXTERN void ec_thread_kill_all(void);
 EC_API_EXTERN void ec_thread_exit(void);
 
-#define RETURN_IF_NOT_MAIN() do{ if (strcmp(ec_thread_getname(EC_SELF), GBL_PROGRAM)) return; }while(0)
+#define RETURN_IF_NOT_MAIN() do{ if (strcmp(ec_thread_getname(EC_PTHREAD_SELF), GBL_PROGRAM)) return; }while(0)
 
 #define CANCELLATION_POINT()  pthread_testcancel()
 
