@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: autoadd.c,v 1.5 2004/07/28 08:06:30 alor Exp $
+    $Id: autoadd.c,v 1.6 2004/10/25 20:35:15 alor Exp $
 */
 
 
@@ -100,17 +100,26 @@ static void parse_arp(struct packet_object *po)
       return;
    
    /* search in target 1 */
-   LIST_FOREACH(t, &GBL_TARGET1->ips, next) 
-      if (!ip_addr_cmp(&t->ip, &po->L3.src)) 
-         if (add_to_victims(&arp_group_one, po) == ESUCCESS)
-            USER_MSG("autoadd: %s %s added to GROUP1\n", ip_addr_ntoa(&po->L3.src, tmp), mac_addr_ntoa(po->L2.src, tmp2));
+   if (GBL_TARGET1->all_ip) {
+      if (add_to_victims(&arp_group_one, po) == ESUCCESS)
+         USER_MSG("autoadd: %s %s added to GROUP1\n", ip_addr_ntoa(&po->L3.src, tmp), mac_addr_ntoa(po->L2.src, tmp2));
+   } else {
+      LIST_FOREACH(t, &GBL_TARGET1->ips, next) 
+         if (!ip_addr_cmp(&t->ip, &po->L3.src)) 
+            if (add_to_victims(&arp_group_one, po) == ESUCCESS)
+               USER_MSG("autoadd: %s %s added to GROUP1\n", ip_addr_ntoa(&po->L3.src, tmp), mac_addr_ntoa(po->L2.src, tmp2));
+   }
    
    /* search in target 2 */
-   LIST_FOREACH(t, &GBL_TARGET2->ips, next) 
-      if (!ip_addr_cmp(&t->ip, &po->L3.src)) 
-         if (add_to_victims(&arp_group_two, po) == ESUCCESS)
-            USER_MSG("autoadd: %s %s added to GROUP2\n", ip_addr_ntoa(&po->L3.src, tmp), mac_addr_ntoa(po->L2.src, tmp2));
-
+   if (GBL_TARGET2->all_ip) {
+      if (add_to_victims(&arp_group_two, po) == ESUCCESS)
+         USER_MSG("autoadd: %s %s added to GROUP2\n", ip_addr_ntoa(&po->L3.src, tmp), mac_addr_ntoa(po->L2.src, tmp2));
+   } else {
+      LIST_FOREACH(t, &GBL_TARGET2->ips, next) 
+         if (!ip_addr_cmp(&t->ip, &po->L3.src)) 
+            if (add_to_victims(&arp_group_two, po) == ESUCCESS)
+               USER_MSG("autoadd: %s %s added to GROUP2\n", ip_addr_ntoa(&po->L3.src, tmp), mac_addr_ntoa(po->L2.src, tmp2));
+   }
 }
 
 /*
